#[non_exhaustive]pub struct ListSessionsOutputBuilder { /* private fields */ }Expand description
A builder for ListSessionsOutput.
Implementations
Sourceimpl ListSessionsOutputBuilder
impl ListSessionsOutputBuilder
Sourcepub fn sessions(self, input: SessionData) -> Self
pub fn sessions(self, input: SessionData) -> Self
Appends an item to sessions.
To override the contents of this collection use set_sessions.
The sessions that match the request.
Sourcepub fn set_sessions(self, input: Option<Vec<SessionData>>) -> Self
pub fn set_sessions(self, input: Option<Vec<SessionData>>) -> Self
The sessions that match the request.
Sourcepub fn get_sessions(&self) -> &Option<Vec<SessionData>>
pub fn get_sessions(&self) -> &Option<Vec<SessionData>>
The sessions that match the request.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.
Sourcepub fn build(self) -> Result<ListSessionsOutput, BuildError>
pub fn build(self) -> Result<ListSessionsOutput, BuildError>
Consumes the builder and constructs a ListSessionsOutput.
This method will fail if any of the following fields are not set: