#[non_exhaustive]pub struct ListSessionsOutput {
pub sessions: Vec<SessionData>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sessions: Vec<SessionData>The sessions that match the request.
next_token: Option<String>A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.
Implementations
Sourceimpl ListSessionsOutput
impl ListSessionsOutput
Sourcepub fn sessions(&self) -> &[SessionData]
pub fn sessions(&self) -> &[SessionData]
The sessions that match the request.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.
Sourceimpl ListSessionsOutput
impl ListSessionsOutput
Sourcepub fn builder() -> ListSessionsOutputBuilder
pub fn builder() -> ListSessionsOutputBuilder
Creates a new builder-style object to manufacture ListSessionsOutput.