SessionDataBuilder

Struct SessionDataBuilder 

#[non_exhaustive]
pub struct SessionDataBuilder { /* private fields */ }
A builder for SessionData.

Implementations

Source

impl SessionDataBuilder

pub fn session_id(self, input: impl Into<String>) -> Self

The session identifier. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API.

This field is required.
pub fn set_session_id(self, input: Option<String>) -> Self

The session identifier. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API.

pub fn get_session_id(&self) -> &Option<String>

The session identifier. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API.

pub fn status(self, input: SessionStatusString) -> Self

The status of the session. Status values are defined as follows:

  • AVAILABLE – The session is open and ready to run a SQL statement.

  • BUSY – The session is currently running a SQL statement.

  • CLOSED – The session is closed and can no longer run SQL statements.

This field is required.
pub fn set_status(self, input: Option<SessionStatusString>) -> Self

The status of the session. Status values are defined as follows:

  • AVAILABLE – The session is open and ready to run a SQL statement.

  • BUSY – The session is currently running a SQL statement.

  • CLOSED – The session is closed and can no longer run SQL statements.

pub fn get_status(&self) -> &Option<SessionStatusString>

The status of the session. Status values are defined as follows:

  • AVAILABLE – The session is open and ready to run a SQL statement.

  • BUSY – The session is currently running a SQL statement.

  • CLOSED – The session is closed and can no longer run SQL statements.

pub fn created_at(self, input: DateTime) -> Self

The date and time (UTC) when the session was created.

This field is required.
pub fn set_created_at(self, input: Option<DateTime>) -> Self

The date and time (UTC) when the session was created.

pub fn get_created_at(&self) -> &Option<DateTime>

The date and time (UTC) when the session was created.

pub fn updated_at(self, input: DateTime) -> Self

The date and time (UTC) that the session metadata was last updated. An example is the time the status last changed.

pub fn set_updated_at(self, input: Option<DateTime>) -> Self

The date and time (UTC) that the session metadata was last updated. An example is the time the status last changed.

pub fn get_updated_at(&self) -> &Option<DateTime>

The date and time (UTC) that the session metadata was last updated. An example is the time the status last changed.

pub fn database(self, input: impl Into<String>) -> Self

The name of the database that the session is connected to.

pub fn set_database(self, input: Option<String>) -> Self

The name of the database that the session is connected to.

pub fn get_database(&self) -> &Option<String>

The name of the database that the session is connected to.

pub fn db_user(self, input: impl Into<String>) -> Self

The database user name.

pub fn set_db_user(self, input: Option<String>) -> Self

The database user name.

pub fn get_db_user(&self) -> &Option<String>

The database user name.

pub fn cluster_identifier(self, input: impl Into<String>) -> Self

The cluster identifier. This element is not returned when connecting to a serverless workgroup.

pub fn set_cluster_identifier(self, input: Option<String>) -> Self

The cluster identifier. This element is not returned when connecting to a serverless workgroup.

pub fn get_cluster_identifier(&self) -> &Option<String>

The cluster identifier. This element is not returned when connecting to a serverless workgroup.

pub fn workgroup_name(self, input: impl Into<String>) -> Self

The serverless workgroup name or Amazon Resource Name (ARN). This element is not returned when connecting to a provisioned cluster.

pub fn set_workgroup_name(self, input: Option<String>) -> Self

The serverless workgroup name or Amazon Resource Name (ARN). This element is not returned when connecting to a provisioned cluster.

pub fn get_workgroup_name(&self) -> &Option<String>

The serverless workgroup name or Amazon Resource Name (ARN). This element is not returned when connecting to a provisioned cluster.

pub fn session_alive_seconds(self, input: i32) -> Self

The number of seconds that the session is kept alive after a query finishes.

pub fn set_session_alive_seconds(self, input: Option<i32>) -> Self

The number of seconds that the session is kept alive after a query finishes.

pub fn get_session_alive_seconds(&self) -> &Option<i32>

The number of seconds that the session is kept alive after a query finishes.

pub fn session_ttl(self, input: DateTime) -> Self

The date and time (UTC) when the session is set to expire and be closed.

pub fn set_session_ttl(self, input: Option<DateTime>) -> Self

The date and time (UTC) when the session is set to expire and be closed.

pub fn get_session_ttl(&self) -> &Option<DateTime>

The date and time (UTC) when the session is set to expire and be closed.

pub fn current_statement_id(self, input: impl Into<String>) -> Self

The identifier of the SQL statement currently running in the session. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. This element is returned only when the session status is BUSY.

pub fn set_current_statement_id(self, input: Option<String>) -> Self

The identifier of the SQL statement currently running in the session. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. This element is returned only when the session status is BUSY.

pub fn get_current_statement_id(&self) -> &Option<String>

The identifier of the SQL statement currently running in the session. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. This element is returned only when the session status is BUSY.

pub fn build(self) -> Result<SessionData, BuildError>

Consumes the builder and constructs a SessionData. This method will fail if any of the following fields are not set: