Struct aws_sdk_redshiftdata::types::builders::SqlParameterBuilder
source · #[non_exhaustive]pub struct SqlParameterBuilder { /* private fields */ }Expand description
A builder for SqlParameter.
Implementations
sourceimpl SqlParameterBuilder
impl SqlParameterBuilder
sourcepub fn value(self, input: impl Into<String>) -> Self
pub fn value(self, input: impl Into<String>) -> Self
The value of the parameter. Amazon Redshift implicitly converts to the proper data type. For more information, see Data types in the Amazon Redshift Database Developer Guide.
sourcepub fn set_value(self, input: Option<String>) -> Self
pub fn set_value(self, input: Option<String>) -> Self
The value of the parameter. Amazon Redshift implicitly converts to the proper data type. For more information, see Data types in the Amazon Redshift Database Developer Guide.
sourcepub fn build(self) -> SqlParameter
pub fn build(self) -> SqlParameter
Consumes the builder and constructs a SqlParameter.