SessionData

Struct SessionData 

#[non_exhaustive]
pub struct SessionData { pub session_id: String, pub status: SessionStatusString, pub created_at: DateTime, pub updated_at: Option<DateTime>, pub database: Option<String>, pub db_user: Option<String>, pub cluster_identifier: Option<String>, pub workgroup_name: Option<String>, pub session_alive_seconds: Option<i32>, pub session_ttl: Option<DateTime>, pub current_statement_id: Option<String>, }
Contains the metadata for a session returned by ListSessions, including its status, compute target, database connection, and lifecycle timestamps.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
session_id: String

The session identifier. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API.

status: SessionStatusString

The status of the session. Status values are defined as follows:

  • AVAILABLE – The session is open and ready to run a SQL statement.

  • BUSY – The session is currently running a SQL statement.

  • CLOSED – The session is closed and can no longer run SQL statements.

created_at: DateTime

The date and time (UTC) when the session was created.

updated_at: Option<DateTime>

The date and time (UTC) that the session metadata was last updated. An example is the time the status last changed.

database: Option<String>

The name of the database that the session is connected to.

db_user: Option<String>

The database user name.

cluster_identifier: Option<String>

The cluster identifier. This element is not returned when connecting to a serverless workgroup.

workgroup_name: Option<String>

The serverless workgroup name or Amazon Resource Name (ARN). This element is not returned when connecting to a provisioned cluster.

session_alive_seconds: Option<i32>

The number of seconds that the session is kept alive after a query finishes.

session_ttl: Option<DateTime>

The date and time (UTC) when the session is set to expire and be closed.

current_statement_id: Option<String>

The identifier of the SQL statement currently running in the session. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. This element is returned only when the session status is BUSY.

Implementations

Source

impl SessionData

pub fn session_id(&self) -> &str

The session identifier. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API.

pub fn status(&self) -> &SessionStatusString

The status of the session. Status values are defined as follows:

  • AVAILABLE – The session is open and ready to run a SQL statement.

  • BUSY – The session is currently running a SQL statement.

  • CLOSED – The session is closed and can no longer run SQL statements.

pub fn created_at(&self) -> &DateTime

The date and time (UTC) when the session was created.

pub fn updated_at(&self) -> Option<&DateTime>

The date and time (UTC) that the session metadata was last updated. An example is the time the status last changed.

pub fn database(&self) -> Option<&str>

The name of the database that the session is connected to.

pub fn db_user(&self) -> Option<&str>

The database user name.

pub fn cluster_identifier(&self) -> Option<&str>

The cluster identifier. This element is not returned when connecting to a serverless workgroup.

pub fn workgroup_name(&self) -> Option<&str>

The serverless workgroup name or Amazon Resource Name (ARN). This element is not returned when connecting to a provisioned cluster.

pub fn session_alive_seconds(&self) -> Option<i32>

The number of seconds that the session is kept alive after a query finishes.

pub fn session_ttl(&self) -> Option<&DateTime>

The date and time (UTC) when the session is set to expire and be closed.

pub fn current_statement_id(&self) -> Option<&str>

The identifier of the SQL statement currently running in the session. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. This element is returned only when the session status is BUSY.

Source

impl SessionData

pub fn builder() -> SessionDataBuilder

Creates a new builder-style object to manufacture SessionData.