#[non_exhaustive]pub struct ListSessionsInputBuilder { /* private fields */ }Expand description
A builder for ListSessionsInput.
Implementations
Sourceimpl ListSessionsInputBuilder
impl ListSessionsInputBuilder
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of sessions to return in the response. If more sessions exist than fit in one response, the operation returns NextToken to paginate the results.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of sessions to return in the response. If more sessions exist than fit in one response, the operation returns NextToken to paginate the results.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of sessions to return in the response. If more sessions exist than fit in one response, the operation returns NextToken to paginate the results.
Sourcepub fn session_id(self, input: impl Into<String>) -> Self
pub fn session_id(self, input: impl Into<String>) -> Self
The identifier of a specific session to return metadata for. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. When you provide SessionId, you can't specify Status, ClusterIdentifier, WorkgroupName, or Database.
Sourcepub fn set_session_id(self, input: Option<String>) -> Self
pub fn set_session_id(self, input: Option<String>) -> Self
The identifier of a specific session to return metadata for. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. When you provide SessionId, you can't specify Status, ClusterIdentifier, WorkgroupName, or Database.
Sourcepub fn get_session_id(&self) -> &Option<String>
pub fn get_session_id(&self) -> &Option<String>
The identifier of a specific session to return metadata for. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. When you provide SessionId, you can't specify Status, ClusterIdentifier, WorkgroupName, or Database.
Sourcepub fn status(self, input: SessionStatusString) -> Self
pub fn status(self, input: SessionStatusString) -> Self
The status of the sessions to list. If no status is specified, sessions with a status of AVAILABLE or BUSY are returned. Status values are defined as follows:
-
AVAILABLE – The session is open and ready to run a SQL statement.
-
BUSY – The session is currently running a SQL statement.
-
CLOSED – The session is closed and can no longer run SQL statements.
Sourcepub fn set_status(self, input: Option<SessionStatusString>) -> Self
pub fn set_status(self, input: Option<SessionStatusString>) -> Self
The status of the sessions to list. If no status is specified, sessions with a status of AVAILABLE or BUSY are returned. Status values are defined as follows:
-
AVAILABLE – The session is open and ready to run a SQL statement.
-
BUSY – The session is currently running a SQL statement.
-
CLOSED – The session is closed and can no longer run SQL statements.
Sourcepub fn get_status(&self) -> &Option<SessionStatusString>
pub fn get_status(&self) -> &Option<SessionStatusString>
The status of the sessions to list. If no status is specified, sessions with a status of AVAILABLE or BUSY are returned. Status values are defined as follows:
-
AVAILABLE – The session is open and ready to run a SQL statement.
-
BUSY – The session is currently running a SQL statement.
-
CLOSED – The session is closed and can no longer run SQL statements.
Sourcepub fn role_level(self, input: bool) -> Self
pub fn role_level(self, input: bool) -> Self
Specifies whether to return all sessions created by the caller's IAM role, including sessions from previous IAM sessions. If false, only sessions created in the current IAM session are returned. The default is true.
Sourcepub fn set_role_level(self, input: Option<bool>) -> Self
pub fn set_role_level(self, input: Option<bool>) -> Self
Specifies whether to return all sessions created by the caller's IAM role, including sessions from previous IAM sessions. If false, only sessions created in the current IAM session are returned. The default is true.
Sourcepub fn get_role_level(&self) -> &Option<bool>
pub fn get_role_level(&self) -> &Option<bool>
Specifies whether to return all sessions created by the caller's IAM role, including sessions from previous IAM sessions. If false, only sessions created in the current IAM session are returned. The default is true.
Sourcepub fn cluster_identifier(self, input: impl Into<String>) -> Self
pub fn cluster_identifier(self, input: impl Into<String>) -> Self
The cluster identifier. Only sessions on this cluster are returned. When providing ClusterIdentifier, then WorkgroupName can't be specified.
Sourcepub fn set_cluster_identifier(self, input: Option<String>) -> Self
pub fn set_cluster_identifier(self, input: Option<String>) -> Self
The cluster identifier. Only sessions on this cluster are returned. When providing ClusterIdentifier, then WorkgroupName can't be specified.
Sourcepub fn get_cluster_identifier(&self) -> &Option<String>
pub fn get_cluster_identifier(&self) -> &Option<String>
The cluster identifier. Only sessions on this cluster are returned. When providing ClusterIdentifier, then WorkgroupName can't be specified.
Sourcepub fn workgroup_name(self, input: impl Into<String>) -> Self
pub fn workgroup_name(self, input: impl Into<String>) -> Self
The serverless workgroup name or Amazon Resource Name (ARN). Only sessions on this workgroup are returned. When providing WorkgroupName, then ClusterIdentifier can't be specified.
Sourcepub fn set_workgroup_name(self, input: Option<String>) -> Self
pub fn set_workgroup_name(self, input: Option<String>) -> Self
The serverless workgroup name or Amazon Resource Name (ARN). Only sessions on this workgroup are returned. When providing WorkgroupName, then ClusterIdentifier can't be specified.
Sourcepub fn get_workgroup_name(&self) -> &Option<String>
pub fn get_workgroup_name(&self) -> &Option<String>
The serverless workgroup name or Amazon Resource Name (ARN). Only sessions on this workgroup are returned. When providing WorkgroupName, then ClusterIdentifier can't be specified.
Sourcepub fn database(self, input: impl Into<String>) -> Self
pub fn database(self, input: impl Into<String>) -> Self
The name of the database. Only sessions connected to this database are returned.
Sourcepub fn set_database(self, input: Option<String>) -> Self
pub fn set_database(self, input: Option<String>) -> Self
The name of the database. Only sessions connected to this database are returned.
Sourcepub fn get_database(&self) -> &Option<String>
pub fn get_database(&self) -> &Option<String>
The name of the database. Only sessions connected to this database are returned.
Sourcepub fn build(self) -> Result<ListSessionsInput, BuildError>
pub fn build(self) -> Result<ListSessionsInput, BuildError>
Consumes the builder and constructs a ListSessionsInput.
Sourceimpl ListSessionsInputBuilder
impl ListSessionsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListSessionsOutput, SdkError<ListSessionsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListSessionsOutput, SdkError<ListSessionsError, HttpResponse>>
Sends a request with this input using the given client.