#[non_exhaustive]pub struct ListSessionsInput {
pub next_token: Option<String>,
pub max_results: Option<i32>,
pub session_id: Option<String>,
pub status: Option<SessionStatusString>,
pub role_level: Option<bool>,
pub cluster_identifier: Option<String>,
pub workgroup_name: Option<String>,
pub database: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.
max_results: Option<i32>The maximum number of sessions to return in the response. If more sessions exist than fit in one response, the operation returns NextToken to paginate the results.
session_id: Option<String>The identifier of a specific session to return metadata for. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. When you provide SessionId, you can't specify Status, ClusterIdentifier, WorkgroupName, or Database.
status: Option<SessionStatusString>The status of the sessions to list. If no status is specified, sessions with a status of AVAILABLE or BUSY are returned. Status values are defined as follows:
-
AVAILABLE – The session is open and ready to run a SQL statement.
-
BUSY – The session is currently running a SQL statement.
-
CLOSED – The session is closed and can no longer run SQL statements.
role_level: Option<bool>Specifies whether to return all sessions created by the caller's IAM role, including sessions from previous IAM sessions. If false, only sessions created in the current IAM session are returned. The default is true.
cluster_identifier: Option<String>The cluster identifier. Only sessions on this cluster are returned. When providing ClusterIdentifier, then WorkgroupName can't be specified.
workgroup_name: Option<String>The serverless workgroup name or Amazon Resource Name (ARN). Only sessions on this workgroup are returned. When providing WorkgroupName, then ClusterIdentifier can't be specified.
database: Option<String>The name of the database. Only sessions connected to this database are returned.
Implementations
Sourceimpl ListSessionsInput
impl ListSessionsInput
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of sessions to return in the response. If more sessions exist than fit in one response, the operation returns NextToken to paginate the results.
Sourcepub fn session_id(&self) -> Option<&str>
pub fn session_id(&self) -> Option<&str>
The identifier of a specific session to return metadata for. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. When you provide SessionId, you can't specify Status, ClusterIdentifier, WorkgroupName, or Database.
Sourcepub fn status(&self) -> Option<&SessionStatusString>
pub fn status(&self) -> Option<&SessionStatusString>
The status of the sessions to list. If no status is specified, sessions with a status of AVAILABLE or BUSY are returned. Status values are defined as follows:
-
AVAILABLE – The session is open and ready to run a SQL statement.
-
BUSY – The session is currently running a SQL statement.
-
CLOSED – The session is closed and can no longer run SQL statements.
Sourcepub fn role_level(&self) -> Option<bool>
pub fn role_level(&self) -> Option<bool>
Specifies whether to return all sessions created by the caller's IAM role, including sessions from previous IAM sessions. If false, only sessions created in the current IAM session are returned. The default is true.
Sourcepub fn cluster_identifier(&self) -> Option<&str>
pub fn cluster_identifier(&self) -> Option<&str>
The cluster identifier. Only sessions on this cluster are returned. When providing ClusterIdentifier, then WorkgroupName can't be specified.
Sourcepub fn workgroup_name(&self) -> Option<&str>
pub fn workgroup_name(&self) -> Option<&str>
The serverless workgroup name or Amazon Resource Name (ARN). Only sessions on this workgroup are returned. When providing WorkgroupName, then ClusterIdentifier can't be specified.
Sourceimpl ListSessionsInput
impl ListSessionsInput
Sourcepub fn builder() -> ListSessionsInputBuilder
pub fn builder() -> ListSessionsInputBuilder
Creates a new builder-style object to manufacture ListSessionsInput.