#[non_exhaustive]pub struct SessionDataBuilder { /* private fields */ }Expand description
A builder for SessionData.
Implementations
Sourceimpl SessionDataBuilder
impl SessionDataBuilder
Sourcepub fn session_id(self, input: impl Into<String>) -> Self
pub fn session_id(self, input: impl Into<String>) -> Self
The session identifier. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API.
This field is required.Sourcepub fn set_session_id(self, input: Option<String>) -> Self
pub fn set_session_id(self, input: Option<String>) -> Self
The session identifier. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API.
Sourcepub fn get_session_id(&self) -> &Option<String>
pub fn get_session_id(&self) -> &Option<String>
The session identifier. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API.
Sourcepub fn status(self, input: SessionStatusString) -> Self
pub fn status(self, input: SessionStatusString) -> Self
The status of the session. Status values are defined as follows:
-
AVAILABLE – The session is open and ready to run a SQL statement.
-
BUSY – The session is currently running a SQL statement.
-
CLOSED – The session is closed and can no longer run SQL statements.
Sourcepub fn set_status(self, input: Option<SessionStatusString>) -> Self
pub fn set_status(self, input: Option<SessionStatusString>) -> Self
The status of the session. Status values are defined as follows:
-
AVAILABLE – The session is open and ready to run a SQL statement.
-
BUSY – The session is currently running a SQL statement.
-
CLOSED – The session is closed and can no longer run SQL statements.
Sourcepub fn get_status(&self) -> &Option<SessionStatusString>
pub fn get_status(&self) -> &Option<SessionStatusString>
The status of the session. Status values are defined as follows:
-
AVAILABLE – The session is open and ready to run a SQL statement.
-
BUSY – The session is currently running a SQL statement.
-
CLOSED – The session is closed and can no longer run SQL statements.
Sourcepub fn created_at(self, input: DateTime) -> Self
pub fn created_at(self, input: DateTime) -> Self
The date and time (UTC) when the session was created.
This field is required.Sourcepub fn set_created_at(self, input: Option<DateTime>) -> Self
pub fn set_created_at(self, input: Option<DateTime>) -> Self
The date and time (UTC) when the session was created.
Sourcepub fn get_created_at(&self) -> &Option<DateTime>
pub fn get_created_at(&self) -> &Option<DateTime>
The date and time (UTC) when the session was created.
Sourcepub fn updated_at(self, input: DateTime) -> Self
pub fn updated_at(self, input: DateTime) -> Self
The date and time (UTC) that the session metadata was last updated. An example is the time the status last changed.
Sourcepub fn set_updated_at(self, input: Option<DateTime>) -> Self
pub fn set_updated_at(self, input: Option<DateTime>) -> Self
The date and time (UTC) that the session metadata was last updated. An example is the time the status last changed.
Sourcepub fn get_updated_at(&self) -> &Option<DateTime>
pub fn get_updated_at(&self) -> &Option<DateTime>
The date and time (UTC) that the session metadata was last updated. An example is the time the status last changed.
Sourcepub fn database(self, input: impl Into<String>) -> Self
pub fn database(self, input: impl Into<String>) -> Self
The name of the database that the session is connected to.
Sourcepub fn set_database(self, input: Option<String>) -> Self
pub fn set_database(self, input: Option<String>) -> Self
The name of the database that the session is connected to.
Sourcepub fn get_database(&self) -> &Option<String>
pub fn get_database(&self) -> &Option<String>
The name of the database that the session is connected to.
Sourcepub fn set_db_user(self, input: Option<String>) -> Self
pub fn set_db_user(self, input: Option<String>) -> Self
The database user name.
Sourcepub fn get_db_user(&self) -> &Option<String>
pub fn get_db_user(&self) -> &Option<String>
The database user name.
Sourcepub fn cluster_identifier(self, input: impl Into<String>) -> Self
pub fn cluster_identifier(self, input: impl Into<String>) -> Self
The cluster identifier. This element is not returned when connecting to a serverless workgroup.
Sourcepub fn set_cluster_identifier(self, input: Option<String>) -> Self
pub fn set_cluster_identifier(self, input: Option<String>) -> Self
The cluster identifier. This element is not returned when connecting to a serverless workgroup.
Sourcepub fn get_cluster_identifier(&self) -> &Option<String>
pub fn get_cluster_identifier(&self) -> &Option<String>
The cluster identifier. This element is not returned when connecting to a serverless workgroup.
Sourcepub fn workgroup_name(self, input: impl Into<String>) -> Self
pub fn workgroup_name(self, input: impl Into<String>) -> Self
The serverless workgroup name or Amazon Resource Name (ARN). This element is not returned when connecting to a provisioned cluster.
Sourcepub fn set_workgroup_name(self, input: Option<String>) -> Self
pub fn set_workgroup_name(self, input: Option<String>) -> Self
The serverless workgroup name or Amazon Resource Name (ARN). This element is not returned when connecting to a provisioned cluster.
Sourcepub fn get_workgroup_name(&self) -> &Option<String>
pub fn get_workgroup_name(&self) -> &Option<String>
The serverless workgroup name or Amazon Resource Name (ARN). This element is not returned when connecting to a provisioned cluster.
Sourcepub fn session_alive_seconds(self, input: i32) -> Self
pub fn session_alive_seconds(self, input: i32) -> Self
The number of seconds that the session is kept alive after a query finishes.
Sourcepub fn set_session_alive_seconds(self, input: Option<i32>) -> Self
pub fn set_session_alive_seconds(self, input: Option<i32>) -> Self
The number of seconds that the session is kept alive after a query finishes.
Sourcepub fn get_session_alive_seconds(&self) -> &Option<i32>
pub fn get_session_alive_seconds(&self) -> &Option<i32>
The number of seconds that the session is kept alive after a query finishes.
Sourcepub fn session_ttl(self, input: DateTime) -> Self
pub fn session_ttl(self, input: DateTime) -> Self
The date and time (UTC) when the session is set to expire and be closed.
Sourcepub fn set_session_ttl(self, input: Option<DateTime>) -> Self
pub fn set_session_ttl(self, input: Option<DateTime>) -> Self
The date and time (UTC) when the session is set to expire and be closed.
Sourcepub fn get_session_ttl(&self) -> &Option<DateTime>
pub fn get_session_ttl(&self) -> &Option<DateTime>
The date and time (UTC) when the session is set to expire and be closed.
Sourcepub fn current_statement_id(self, input: impl Into<String>) -> Self
pub fn current_statement_id(self, input: impl Into<String>) -> Self
The identifier of the SQL statement currently running in the session. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. This element is returned only when the session status is BUSY.
Sourcepub fn set_current_statement_id(self, input: Option<String>) -> Self
pub fn set_current_statement_id(self, input: Option<String>) -> Self
The identifier of the SQL statement currently running in the session. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. This element is returned only when the session status is BUSY.
Sourcepub fn get_current_statement_id(&self) -> &Option<String>
pub fn get_current_statement_id(&self) -> &Option<String>
The identifier of the SQL statement currently running in the session. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. This element is returned only when the session status is BUSY.
Sourcepub fn build(self) -> Result<SessionData, BuildError>
pub fn build(self) -> Result<SessionData, BuildError>
Consumes the builder and constructs a SessionData.
This method will fail if any of the following fields are not set: